@@ -16,11 +16,14 @@ After that, you can set config attributes:
 import my.config as config
 
 
-def set_repo(name: str, repo):
+from pathlib import Path
+from typing import Union
+def set_repo(name: str, repo: Union[Path, str]) -> None:
     from .core.init import assign_module
     from . common import import_from
 
-    module = import_from(repo, name)
+    r = Path(repo)
+    module = import_from(r.parent, name)
     assign_module('my.config.repos', name, module)
 
 
